@@ -2,13 +2,7 @@
 # SPDX-License-Identifier: MIT
 
 import collections
-import contextlib
-import io
-import os
 import re
-import sys
-import tempfile
-from typing import Iterator, List
 
 from specfile.constants import ARCH_NAMES
 from specfile.exceptions import SpecfileException
@@ -120,30 +114,6 @@ class NEVRA(NEVR):
         return cls(name=n, epoch=int(e) if e else 0, version=v, release=r, arch=a)
 
 
-@contextlib.contextmanager
-def capture_stderr() -> Iterator[List[bytes]]:
-    """
-    Context manager for capturing output to stderr. A stderr output of anything run
-    in its context will be captured in the target variable of the with statement.
-
-    Yields:
-        List of captured lines.
-    """
-    fileno = sys.__stderr__.fileno()
-    with tempfile.TemporaryFile() as stderr, os.fdopen(os.dup(fileno)) as backup:
-        sys.stderr.flush()
-        os.dup2(stderr.fileno(), fileno)
-        data: List[bytes] = []
-        try:
-            yield data
-        finally:
-            sys.stderr.flush()
-            os.dup2(backup.fileno(), fileno)
-            stderr.flush()
-            stderr.seek(0, io.SEEK_SET)
-            data.extend(stderr.readlines())
-
-
 def get_filename_from_location(location: str) -> str:
     """
     Extracts filename from given source location.
